@@ -4,6 +4,8 @@ from enum import Enum
 class ChartKind(str, Enum):
     AREA = "area"
     BIG_NUMBER = "big_number"
+    CUSTOM = "custom"
+    FUNNEL = "funnel"
     HORIZONTAL_BAR = "horizontal_bar"
     LINE = "line"
     MIXED = "mixed"
