@@ -1,66 +1,66 @@
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Type
-from typing import TYPE_CHECKING
-from typing import TypeVar
-from typing import Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
-from ..models.dbt_gitlab_project_config_type import DbtGitlabProjectConfigType
-from ..types import UNSET
-from ..types import Unset
+from ..models.dbt_project_type_gitlab import DbtProjectTypeGITLAB
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.dbt_gitlab_project_config_environment_item import DbtGitlabProjectConfigEnvironmentItem
+    from ..models.dbt_project_environment_variable import DbtProjectEnvironmentVariable
 
 
 T = TypeVar("T", bound="DbtGitlabProjectConfig")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class DbtGitlabProjectConfig:
     """
     Attributes:
-        type (DbtGitlabProjectConfigType):
+        type (DbtProjectTypeGITLAB):
         personal_access_token (str):
         repository (str):
         branch (str):
         project_sub_path (str):
         target (Union[Unset, str]):
-        environment (Union[Unset, List['DbtGitlabProjectConfigEnvironmentItem']]):
+        environment (Union[Unset, List['DbtProjectEnvironmentVariable']]):
         host_domain (Union[Unset, str]):
     """
 
-    type: DbtGitlabProjectConfigType
+    type: DbtProjectTypeGITLAB
     personal_access_token: str
     repository: str
     branch: str
     project_sub_path: str
     target: Union[Unset, str] = UNSET
-    environment: Union[Unset, List["DbtGitlabProjectConfigEnvironmentItem"]] = UNSET
+    environment: Union[Unset, List["DbtProjectEnvironmentVariable"]] = UNSET
     host_domain: Union[Unset, str] = UNSET
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         type = self.type.value
 
         personal_access_token = self.personal_access_token
+
         repository = self.repository
+
         branch = self.branch
+
         project_sub_path = self.project_sub_path
+
         target = self.target
+
         environment: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.environment, Unset):
             environment = []
             for environment_item_data in self.environment:
                 environment_item = environment_item_data.to_dict()
-
                 environment.append(environment_item)
 
         host_domain = self.host_domain
 
         field_dict: Dict[str, Any] = {}
+        field_dict.update(self.additional_properties)
         field_dict.update(
             {
                 "type": type,
@@ -81,10 +81,12 @@ class DbtGitlabProjectConfig:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.dbt_gitlab_project_config_environment_item import DbtGitlabProjectConfigEnvironmentItem
+        from ..models.dbt_project_environment_variable import (
+            DbtProjectEnvironmentVariable,
+        )
 
         d = src_dict.copy()
-        type = DbtGitlabProjectConfigType(d.pop("type"))
+        type = DbtProjectTypeGITLAB(d.pop("type"))
 
         personal_access_token = d.pop("personal_access_token")
 
@@ -99,7 +101,7 @@ class DbtGitlabProjectConfig:
         environment = []
         _environment = d.pop("environment", UNSET)
         for environment_item_data in _environment or []:
-            environment_item = DbtGitlabProjectConfigEnvironmentItem.from_dict(environment_item_data)
+            environment_item = DbtProjectEnvironmentVariable.from_dict(environment_item_data)
 
             environment.append(environment_item)
 
@@ -116,4 +118,21 @@ class DbtGitlabProjectConfig:
             host_domain=host_domain,
         )
 
+        dbt_gitlab_project_config.additional_properties = d
         return dbt_gitlab_project_config
+
+    @property
+    def additional_keys(self) -> List[str]:
+        return list(self.additional_properties.keys())
+
+    def __getitem__(self, key: str) -> Any:
+        return self.additional_properties[key]
+
+    def __setitem__(self, key: str, value: Any) -> None:
+        self.additional_properties[key] = value
+
+    def __delitem__(self, key: str) -> None:
+        del self.additional_properties[key]
+
+    def __contains__(self, key: str) -> bool:
+        return key in self.additional_properties
