@@ -1,13 +1,14 @@
 from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="PartialOmitOrganizationOrganizationUuidOrNeedsProject")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class PartialOmitOrganizationOrganizationUuidOrNeedsProject:
     """Make all properties in T optional
 
@@ -20,10 +21,11 @@ class PartialOmitOrganizationOrganizationUuidOrNeedsProject:
     name: Union[Unset, str] = UNSET
     chart_colors: Union[Unset, List[str]] = UNSET
     default_project_uuid: Union[Unset, str] = UNSET
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
+
         chart_colors: Union[Unset, List[str]] = UNSET
         if not isinstance(self.chart_colors, Unset):
             chart_colors = self.chart_colors
