@@ -1,11 +1,12 @@
 from typing import Any, Dict, List, Type, TypeVar
 
-import attr
+from attrs import define as _attrs_define
+from attrs import field as _attrs_field
 
 T = TypeVar("T", bound="PickCreateDbtCloudIntegrationMetricsJobId")
 
 
-@attr.s(auto_attribs=True)
+@_attrs_define
 class PickCreateDbtCloudIntegrationMetricsJobId:
     """From T, pick a set of properties whose keys are in the union K
 
@@ -14,7 +15,7 @@ class PickCreateDbtCloudIntegrationMetricsJobId:
     """
 
     metrics_job_id: str
-    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
+    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         metrics_job_id = self.metrics_job_id
